#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 store-core
version:              0.4.4.7
visibility:           public
id:                   store-core-0.4.4.7-6zTggZnrugRA20JpEqBioz
key:                  store-core-0.4.4.7-6zTggZnrugRA20JpEqBioz
license:              MIT
copyright:            2016 FP Complete
maintainer:           Michael Sloan <mgsloan@gmail.com>
homepage:             https://github.com/fpco/store#readme
synopsis:             Fast and lightweight binary serialization
category:             Serialization, Data
abi:                  b9943d42d38c2fad086dd4fc212778c6
exposed:              True
exposed-modules:      Data.Store.Core
hidden-modules:       Paths_store_core
import-dirs:          /usr/lib/ghc-9.6.6/site-local/store-core-0.4.4.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/store-core-0.4.4.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/store-core-0.4.4.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-store-core
hs-libraries:         HSstore-core-0.4.4.7-6zTggZnrugRA20JpEqBioz
depends:
    base-4.18.2.1 bytestring-0.11.5.3 ghc-prim-0.10.0
    primitive-0.9.1.0-CEhZf8K56BF7coEYBbWRmS text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-store-core/html/store-core.haddock
haddock-html:         /usr/share/doc/haskell-store-core/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

